<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt_PT" sourcelanguage="en">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../src/tiled/aboutdialog.ui" line="+14"/>
        <source>About Tiled</source>
        <translatorcomment>Acerca do Tiled</translatorcomment>
        <translation></translation>
    </message>
    <message>
        <location line="+96"/>
        <source>OK</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/tiled/aboutdialog.cpp" line="+32"/>
        <source>&lt;p align=&quot;center&quot;&gt;&lt;font size=&quot;+2&quot;&gt;&lt;b&gt;Tiled Map Editor&lt;/b&gt;&lt;/font&gt;&lt;br&gt;&lt;i&gt;Version %1&lt;/i&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot;&gt;Copyright 2008-2010 Thorbj&amp;oslash;rn Lindeijer&lt;br&gt;(see the AUTHORS file for a full list of contributors)&lt;/p&gt;
&lt;p align=&quot;center&quot;&gt;You may modify and redistribute this program under the terms of the GPL (version 2 or later). A copy of the GPL is contained in the &apos;COPYING&apos; file distributed with Tiled.&lt;/p&gt;
&lt;p align=&quot;center&quot;&gt;&lt;a href=&quot;http://www.mapeditor.org/&quot;&gt;http://www.mapeditor.org/&lt;/a&gt;&lt;/p&gt;
</source>
        <translation>&lt;p align=&quot;center&quot;&gt;&lt;font size=&quot;+2&quot;&gt;&lt;b&gt;Tiled - Editor de Mapas&lt;/b&gt;&lt;/font&gt;&lt;br&gt;&lt;i&gt;Version %1&lt;/i&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot;&gt;Copyright 2008-2010 Thorbj&amp;oslash;rn Lindeijer&lt;br&gt;(ver o ficheiro AUTHORS para a lista completa de contribuitores)&lt;/p&gt;
&lt;p align=&quot;center&quot;&gt;Pode modificar e redistribuir este programa sobre os termos GPL (versão 2 ou postrior). Uma cópia da GPL está contida no ficheiro &apos;COPYING&apos; distribuid com o Tiled.&lt;/p&gt;
&lt;p align=&quot;center&quot;&gt;&lt;a href=&quot;http://www.mapeditor.org/&quot;&gt;http://www.mapeditor.org/&lt;/a&gt;&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>CommandDialog</name>
    <message>
        <location filename="../src/tiled/commanddialog.ui" line="+14"/>
        <source>Properties</source>
        <translation type="unfinished">Propriedades</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Save map before executing</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/tiled/mainwindow.ui" line="+17"/>
        <source>Tiled</source>
        <translation></translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;File</source>
        <translation>&amp;Ficheiro</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Help</source>
        <translation>&amp;Ajuda</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Map</source>
        <translation>&amp;Mapa</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>&amp;View</source>
        <translation>&amp;Ver</translation>
    </message>
    <message>
        <source>&amp;Layer</source>
        <translation type="obsolete">&amp;Camada</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Main Toolbar</source>
        <translation></translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Open...</source>
        <translation>&amp;Abrir...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Save</source>
        <translation>&amp;Salvar</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Quit</source>
        <translation>&amp;Sair</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>&amp;Copy</source>
        <translation>&amp;Copiar</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>&amp;Paste</source>
        <translation>&amp;Colar</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;About Tiled</source>
        <translation>&amp;Acerca do Tiled</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>About Qt</source>
        <translation>Acerca do Qt</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>&amp;Resize Map...</source>
        <translation>&amp;Redimensionar Mapa...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Map &amp;Properties...</source>
        <translation>&amp;Propriedades do Mapa...</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>AutoMap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+29"/>
        <source>&amp;New...</source>
        <translation>&amp;Novo...</translation>
    </message>
    <message>
        <location line="+98"/>
        <source>&amp;Export As...</source>
        <translation>&amp;Exportar Como...</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ctrl+E</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Add External Tileset...</source>
        <translation>&amp;Adicionar Tileset Externo...</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Snap to Grid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>C&amp;lose All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ctrl+Shift+W</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-329"/>
        <source>&amp;Recent Files</source>
        <translation>Ficheiros &amp;Recentes</translation>
    </message>
    <message>
        <location line="+186"/>
        <source>Show &amp;Grid</source>
        <translation>Mostrar &amp;Grelha</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ctrl+G</source>
        <translation></translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Save &amp;As...</source>
        <translation>Salvar &amp;Como...</translation>
    </message>
    <message>
        <source>Move Layer &amp;Up</source>
        <translation type="obsolete">Mover Camada para &amp;Cima</translation>
    </message>
    <message>
        <source>Move Layer Dow&amp;n</source>
        <translation type="obsolete">Mover Camada para &amp;Baixo</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation type="obsolete">Selecionar &amp;Tudo</translation>
    </message>
    <message>
        <source>Select &amp;None</source>
        <translation type="obsolete">Limpar &amp;Selecção</translation>
    </message>
    <message>
        <source>New...</source>
        <translation type="obsolete">Novo...</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>New &amp;Tileset...</source>
        <translation>Novo &amp;Tileset...</translation>
    </message>
    <message>
        <source>&amp;Remove Layer</source>
        <translation type="obsolete">&amp;Remover Camada</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <source>Add &amp;Tile Layer...</source>
        <translation type="obsolete">Adicionar Camada de &amp;Tiles...</translation>
    </message>
    <message>
        <source>Add &amp;Object Layer...</source>
        <translation type="obsolete">Adicionar Camada de &amp;Objectos...</translation>
    </message>
    <message>
        <source>&amp;Duplicate Layer</source>
        <translation type="obsolete">&amp;Duplicar Camada</translation>
    </message>
    <message>
        <source>Layer &amp;Properties...</source>
        <translation type="obsolete">&amp;Propriedades da Camada...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Zoom In</source>
        <translation>Aumentar</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Zoom Out</source>
        <translation>Diminuir</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Normal Size</source>
        <translation>Tamanho Normal</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ctrl+0</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Save As Image...</source>
        <translation>Salvar como Imagem...</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Cu&amp;t</source>
        <translation>Cor&amp;tar</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Offset Map...</source>
        <translation>&amp;Deslocamento do mapa...</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Offsets everything in a layer</source>
        <translation>Deslucar tudo numa camada</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Pre&amp;ferences...</source>
        <translation>Pre&amp;ferências...</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Clear Recent Files</source>
        <translation>Limpar Ficheiros Recentes</translation>
    </message>
</context>
<context>
    <name>MapObjectItem</name>
    <message>
        <source>&amp;Duplicate</source>
        <translation type="obsolete">&amp;Duplicar</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation type="obsolete">&amp;Remover</translation>
    </message>
    <message>
        <source>&amp;Properties...</source>
        <translation type="obsolete">&amp;Propriedades...</translation>
    </message>
    <message>
        <source>&amp;Duplicate Object</source>
        <translation type="obsolete">&amp;Duplicar Objecto</translation>
    </message>
    <message>
        <source>&amp;Remove Object</source>
        <translation type="obsolete">&amp;Remover Objecto</translation>
    </message>
    <message>
        <source>Object &amp;Properties...</source>
        <translation type="obsolete">Objectos &amp;Propriedades...</translation>
    </message>
</context>
<context>
    <name>MapReader</name>
    <message>
        <location filename="../src/libtiled/mapreader.cpp" line="+132"/>
        <source>Not a map file.</source>
        <translation type="unfinished">Não é um ficheiro de Mapa.</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Not a tileset file.</source>
        <translation type="unfinished">Não é um ficheiro de tileset.</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>%3

Line %1, column %2</source>
        <translation type="unfinished">%3

Linha %1, coluna %2</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>File not found: %1</source>
        <translation type="unfinished">Ficheiro não encontrado: %1</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Unable to read file: %1</source>
        <translation type="unfinished">Incapaz de ler ficheiro: %1</translation>
    </message>
    <message>
        <location line="+61"/>
        <source>Unsupported map orientation: &quot;%1&quot;</source>
        <translation type="unfinished">Orientação de mapa não suportado: &quot;%1&quot;</translation>
    </message>
    <message>
        <location line="+56"/>
        <source>Invalid tileset parameters for tileset &apos;%1&apos;</source>
        <translation type="unfinished">Parametros de tileset inválidos para tileset &apos;%1&apos;</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Error while loading tileset &apos;%1&apos;: %2</source>
        <translation type="unfinished">Erro a carregar tileset &apos;%1&apos;: %2</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Invalid tile ID: %1</source>
        <translation type="unfinished">Tile ID inválido: %1</translation>
    </message>
    <message>
        <location line="+34"/>
        <source>Error loading tileset image:
&apos;%1&apos;</source>
        <translation type="unfinished">Erroa a Carregar a imagem de tileser:
&apos;%1&apos;</translation>
    </message>
    <message>
        <location line="+64"/>
        <source>Too many &lt;tile&gt; elements</source>
        <translation type="unfinished">Demaseados elementos &lt;tile&gt;</translation>
    </message>
    <message>
        <location line="+11"/>
        <location line="+66"/>
        <location line="+39"/>
        <location line="+103"/>
        <source>Invalid tile: %1</source>
        <translation type="unfinished">Tile inválido: %1</translation>
    </message>
    <message>
        <location line="-188"/>
        <source>Unknown encoding: %1</source>
        <translation type="unfinished">Codificação desconhecida: %1</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Compression method &apos;%1&apos; not supported</source>
        <translation type="unfinished">Método de compressão &apos;%1&apos; não suportado</translation>
    </message>
    <message>
        <location line="+6"/>
        <location line="+39"/>
        <source>Corrupt layer data for layer &apos;%1&apos;</source>
        <translation type="unfinished">Data de Camada corrumpido para a Camada &apos;%1&apos;</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Unable to parse tile at (%1,%2) on layer &apos;%3&apos;</source>
        <translation type="unfinished">Incapaz de intrepertar tile em (%1,%2) na camada &apos;%3&apos;</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Invalid global tile id (less than 0): %1</source>
        <translation type="unfinished">ID global de tile inválido (inferior a 0): %1</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Tile used but no tilesets specified</source>
        <translation type="unfinished">Tile usado mas nenhum tileset especificado</translation>
    </message>
    <message>
        <location filename="../src/libtiled/mapwriter.cpp" line="+102"/>
        <source>Could not open file for writing.</source>
        <translation type="unfinished">Impossivel abrir para escrita.</translation>
    </message>
</context>
<context>
    <name>NewMapDialog</name>
    <message>
        <location filename="../src/tiled/newmapdialog.ui" line="+14"/>
        <source>New Map</source>
        <translation>Novo Mapa</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Map size</source>
        <translation>Tamanho do Mapa</translation>
    </message>
    <message>
        <location line="+6"/>
        <location line="+55"/>
        <source>Width:</source>
        <translation>Largura:</translation>
    </message>
    <message>
        <location line="-32"/>
        <location line="+55"/>
        <source>Height:</source>
        <translation>Altura:</translation>
    </message>
    <message>
        <location line="-29"/>
        <source>Tile size</source>
        <translation>Tamanho do Tile</translation>
    </message>
    <message>
        <location line="+78"/>
        <source>Map</source>
        <translation>Mapa</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Orientation:</source>
        <translation>Orientação:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Orthogonal</source>
        <translation>Ortogonal</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Isometric</source>
        <translation>Isométrica</translation>
    </message>
</context>
<context>
    <name>NewTilesetDialog</name>
    <message>
        <location filename="../src/tiled/newtilesetdialog.ui" line="+6"/>
        <source>New Tileset</source>
        <translation>Novo Tileset</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Tileset</source>
        <translation></translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Name:</source>
        <translation>&amp;Nome:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Image:</source>
        <translation>Imagem:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Browse...</source>
        <translation>&amp;Explorar...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Use transparent color:</source>
        <translation>Usar cor transparente:</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Tiles</source>
        <translation></translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Tile width:</source>
        <translation>Largura:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Margin:</source>
        <translation>Margem:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Tile height:</source>
        <translation>Altura:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Spacing:</source>
        <translation>Espaçamento:</translation>
    </message>
</context>
<context>
    <name>ObjectPropertiesDialog</name>
    <message>
        <location filename="../src/tiled/objectpropertiesdialog.ui" line="+26"/>
        <source>Form</source>
        <translation>De</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Name:</source>
        <translation>Nome:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Position</source>
        <translation>Posição</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <location line="+42"/>
        <source>Size</source>
        <translation>Tamanho</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Width:</source>
        <translation>Largura:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Height:</source>
        <translation>Altura:</translation>
    </message>
</context>
<context>
    <name>OffsetMapDialog</name>
    <message>
        <location filename="../src/tiled/offsetmapdialog.ui" line="+17"/>
        <source>Offset Map</source>
        <translation>Deslocamento do Mapa</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Offset Contents of Map</source>
        <translation>Deslocamento dos conteúdos do Mapa</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <location line="+23"/>
        <location line="+43"/>
        <source>Wrap</source>
        <translation>Embrulhar</translation>
    </message>
    <message>
        <location line="-36"/>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Layers:</source>
        <translation>Camadas:</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>All Visible Layers</source>
        <translation>Todas as Camadas Visíveis</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>All Layers</source>
        <translation>Todas as Camadas</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Selected Layer</source>
        <translation>Selecionar Camada</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Bounds:</source>
        <translation>Limites:</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Whole Map</source>
        <translation>Todo o Mapa</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Current Selection</source>
        <translation>Seleção Currente</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../src/tiled/preferencesdialog.ui" line="+14"/>
        <source>Preferences</source>
        <translation>Preferências</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Saving and Loading</source>
        <translation>Guardar e Abrir</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Store tile layer data as:</source>
        <translation>&amp;Armazenar dados das camadas de tiles como:</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>XML</source>
        <translation>XML</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Base64 (uncompressed)</source>
        <translation>Base64 (descomprimido)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Base64 (gzip compressed)</source>
        <translation>Base64 (comprimido com gzip)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Base64 (zlib compressed)</source>
        <translation>Base64 (comprimido com zlib)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>CSV</source>
        <translation></translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Reload tileset images when they change</source>
        <translation>&amp;Recarregar imagens de tileset quando existirem mudanças</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Not enabled by default since a reference to an external DTD is known to cause problems with some XML parsers.</source>
        <translation>Desabilitado por defeito porque a referencia para um DTD externo é conhecida por causar problemas para alguns analisadores de XML.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Include &amp;DTD reference in saved maps</source>
        <translation>Incluir referências &amp;DTD nos mapas guardados</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Interface</source>
        <translation>Interface</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Language:</source>
        <translation>&amp;Linguagem:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Hardware &amp;accelerated drawing (OpenGL)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PropertiesDialog</name>
    <message>
        <location filename="../src/tiled/propertiesdialog.ui" line="+14"/>
        <source>Properties</source>
        <translation>Propriedades</translation>
    </message>
</context>
<context>
    <name>ResizeDialog</name>
    <message>
        <location filename="../src/tiled/resizedialog.ui" line="+14"/>
        <source>Resize</source>
        <translation>Redimensionar</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Size</source>
        <translation>Tamanho</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Width:</source>
        <translation>Largura:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Height:</source>
        <translation>altura:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Offset</source>
        <translation></translation>
    </message>
    <message>
        <location line="+6"/>
        <source>X:</source>
        <translation></translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Y:</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>SaveAsImageDialog</name>
    <message>
        <location filename="../src/tiled/saveasimagedialog.ui" line="+14"/>
        <source>Save As Image</source>
        <translation>Salvar Como Imagem</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Location</source>
        <translation>Localização</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Name:</source>
        <translation>Nome:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>&amp;Browse...</source>
        <translation>&amp;Explorar...</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Settings</source>
        <translation>Preferências</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Only include &amp;visible layers</source>
        <translation>Apenas incluir &amp;camadas visíveis</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Use current &amp;zoom level</source>
        <translation>Usar o nivel de &amp;aumentação corrente</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Draw tile grid</source>
        <translation>&amp;Desenhar tile como grelha</translation>
    </message>
</context>
<context>
    <name>Tengine::TenginePlugin</name>
    <message>
        <location filename="../src/plugins/tengine/tengineplugin.cpp" line="+50"/>
        <source>Could not open file for writing.</source>
        <translation type="unfinished">Impossivel abrir para escrita.</translation>
    </message>
    <message>
        <location line="+243"/>
        <source>T-Engine4 map files (*.lua)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::AutoMapper</name>
    <message>
        <location filename="../src/tiled/automap.cpp" line="+116"/>
        <source>Multiple layers %1 found!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+115"/>
        <source>No ruleRegions layer found!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>No set layers found!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>No ruleSet layer found!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+208"/>
        <source>Tile</source>
        <translation type="unfinished">Tile</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::AutomaticMappingManager</name>
    <message>
        <location line="+491"/>
        <source>No set layer found!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Apply AutoMap rules</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+18"/>
        <source>No rules file found at:
%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Error opening rules file:
%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+19"/>
        <source>File not found:
%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Opening rules map failed:
%1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::BucketFillTool</name>
    <message>
        <location filename="../src/tiled/bucketfilltool.cpp" line="+39"/>
        <location line="+133"/>
        <source>Bucket Fill Tool</source>
        <translation>Ferramenta de Preenchimento</translation>
    </message>
    <message>
        <location line="-130"/>
        <location line="+131"/>
        <source>F</source>
        <translation>F</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::CommandButton</name>
    <message>
        <location filename="../src/tiled/commandbutton.cpp" line="+48"/>
        <source>Execute Command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>F5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+39"/>
        <location line="+61"/>
        <source>Error Executing Command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-60"/>
        <source>You do not have any commands setup.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Edit commands...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+50"/>
        <source>Edit Commands...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+9"/>
        <source>There was an error running the command</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::CommandDataModel</name>
    <message>
        <location filename="../src/tiled/commanddatamodel.cpp" line="+74"/>
        <source>Open in text editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+90"/>
        <location line="+67"/>
        <source>&lt;new command&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-59"/>
        <source>Set a name for this command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Set the shell command to execute</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Show or hide this command in the command list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Add a new command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+100"/>
        <source>Name</source>
        <translation type="unfinished">Nome</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Enable</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::CommandDialog</name>
    <message>
        <location filename="../src/tiled/commanddialog.cpp" line="+35"/>
        <source>Edit Commands</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::CreateObjectTool</name>
    <message>
        <location filename="../src/tiled/createobjecttool.cpp" line="+42"/>
        <location line="+111"/>
        <source>O</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Insert Objects</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Insert Tile Objects</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>T</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::Eraser</name>
    <message>
        <location filename="../src/tiled/eraser.cpp" line="+34"/>
        <location line="+36"/>
        <source>Eraser</source>
        <translation>Apagador</translation>
    </message>
    <message>
        <location line="-33"/>
        <location line="+34"/>
        <source>E</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::LayerDock</name>
    <message>
        <location filename="../src/tiled/layerdock.cpp" line="+178"/>
        <source>Layers</source>
        <translation>Camadas</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Opacity:</source>
        <translation>Transparência:</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::LayerModel</name>
    <message>
        <location filename="../src/tiled/layermodel.cpp" line="+122"/>
        <source>Layer</source>
        <translation>Camada</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::LayerView</name>
    <message>
        <source>Properties...</source>
        <translation type="obsolete">Propriedades...</translation>
    </message>
    <message>
        <source>Layer</source>
        <translation type="obsolete">Camada</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::MainWindow</name>
    <message>
        <location filename="../src/tiled/mainwindow.cpp" line="+129"/>
        <location line="+10"/>
        <source>Undo</source>
        <translation>Desfazer</translation>
    </message>
    <message>
        <location line="-9"/>
        <location line="+8"/>
        <source>Redo</source>
        <translation>Refazer</translation>
    </message>
    <message>
        <source>Error while opening map</source>
        <translation type="obsolete">Erro na abertura do mapa</translation>
    </message>
    <message>
        <location line="+391"/>
        <source>Open Map</source>
        <translation>Abrir Mapa</translation>
    </message>
    <message>
        <location line="-13"/>
        <location line="+79"/>
        <source>Tiled map files (*.tmx)</source>
        <translation>Ficheiros de mapa do Tiled (*.tmx)</translation>
    </message>
    <message>
        <source>Error while saving map</source>
        <translation type="obsolete">Erro a salvar o mapa</translation>
    </message>
    <message>
        <location line="-425"/>
        <source>Ctrl+=</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>+</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>-</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+19"/>
        <location line="+962"/>
        <source>&amp;Layer</source>
        <translation>&amp;Camada</translation>
    </message>
    <message>
        <location line="-711"/>
        <source>Error Opening Map</source>
        <translation>Erro na abertura do mapa</translation>
    </message>
    <message>
        <location line="+69"/>
        <location line="+138"/>
        <source>All Files (*)</source>
        <translation>Todos os Ficheiros (*)</translation>
    </message>
    <message>
        <location line="-97"/>
        <location line="+144"/>
        <source>Error Saving Map</source>
        <translation>Erro a salvar o mapa</translation>
    </message>
    <message>
        <location line="-108"/>
        <source>untitled.tmx</source>
        <translation>sem-nome.tmx</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Unsaved Changes</source>
        <translation>Mudanças por salvar</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>There are unsaved changes. Do you want to save now?</source>
        <translation>Existem mudanças por salvar. Deseja salvar agora?</translation>
    </message>
    <message>
        <location line="+52"/>
        <source>Export As...</source>
        <translation>Exportar Como...</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Unknown File Format</source>
        <translation>Formato de Ficheiro Desconhecido</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The given filename does not have any known file extension.</source>
        <translation>O ficheiro especificado não tem nenhuma extenção de ficheiro conhecida.</translation>
    </message>
    <message>
        <location line="+47"/>
        <source>Cut</source>
        <translation>Cortar</translation>
    </message>
    <message>
        <location line="+377"/>
        <source>[*]%1 - Tiled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Tilesets</source>
        <translation type="obsolete">Adicionar Tileset</translation>
    </message>
    <message>
        <location line="-280"/>
        <source>Add External Tileset</source>
        <translation>Adicionar Tileset Externo</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Tiled tileset files (*.tsx)</source>
        <translation>Ficheiros de tileset do Tiled (*.tmx)</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Error Reading Tileset</source>
        <translation>Erro na Leitura do Tileset</translation>
    </message>
    <message>
        <location line="+46"/>
        <source>Map</source>
        <translation>Mapa</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Automatic Mapping</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+123"/>
        <source>%1%</source>
        <translation></translation>
    </message>
    <message>
        <source>Add Tile Layer</source>
        <translation type="obsolete">Adicionar Camade de Tiles</translation>
    </message>
    <message>
        <source>Add Object Layer</source>
        <translation type="obsolete">Adicionar Camade de Objectos</translation>
    </message>
    <message>
        <source>Layer name:</source>
        <translation type="obsolete">Nome da Camada:</translation>
    </message>
    <message>
        <source>New Layer</source>
        <translation type="obsolete">Nova Camada</translation>
    </message>
    <message>
        <source>Layer</source>
        <translation type="obsolete">Camada</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::MapDocument</name>
    <message>
        <location filename="../src/tiled/mapdocument.cpp" line="+105"/>
        <source>untitled.tmx</source>
        <translation type="unfinished">sem-nome.tmx</translation>
    </message>
    <message>
        <location line="+39"/>
        <source>Resize Map</source>
        <translation>Redimensionar Mapa</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Offset Map</source>
        <translation>Deslocamento do Mapa</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Tile Layer %1</source>
        <translation>Camade de Tiles %1</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Object Layer %1</source>
        <translation>Camada de Objectos %1</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Copy of %1</source>
        <translation>Copia de %1</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Duplicate Layer</source>
        <translation>Duplicar Camada</translation>
    </message>
    <message>
        <location line="+120"/>
        <source>Tile</source>
        <translation type="unfinished">Tile</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Tileset Changes</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::MapDocumentActionHandler</name>
    <message>
        <location filename="../src/tiled/mapdocumentactionhandler.cpp" line="+100"/>
        <source>Select &amp;All</source>
        <translation>Selecionar &amp;Tudo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Select &amp;None</source>
        <translation>Limpar &amp;Selecção</translation>
    </message>
    <message>
        <location line="-56"/>
        <source>Ctrl+Shift+A</source>
        <translation></translation>
    </message>
    <message>
        <location line="+58"/>
        <source>Add &amp;Tile Layer...</source>
        <translation>Adicionar Camada de &amp;Tiles...</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Add &amp;Object Layer...</source>
        <translation>Adicionar Camada de &amp;Objectos...</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&amp;Duplicate Layer</source>
        <translation>&amp;Duplicar Camada</translation>
    </message>
    <message>
        <location line="-54"/>
        <source>Ctrl+Shift+D</source>
        <translation></translation>
    </message>
    <message>
        <location line="+55"/>
        <source>&amp;Remove Layer</source>
        <translation>&amp;Remover Camada</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Move Layer &amp;Up</source>
        <translation>Mover Camada para &amp;Cima</translation>
    </message>
    <message>
        <location line="-47"/>
        <source>Ctrl+Shift+Up</source>
        <translation></translation>
    </message>
    <message>
        <location line="+48"/>
        <source>Move Layer Dow&amp;n</source>
        <translation>Mover Camada para &amp;Baixo</translation>
    </message>
    <message>
        <location line="-43"/>
        <source>Ctrl+Shift+Down</source>
        <translation></translation>
    </message>
    <message>
        <location line="+44"/>
        <source>Layer &amp;Properties...</source>
        <translation>&amp;Propriedades da Camada...</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::NewMapDialog</name>
    <message>
        <source>Layer 1</source>
        <translation type="obsolete">Camada1</translation>
    </message>
    <message>
        <location filename="../src/tiled/newmapdialog.cpp" line="+81"/>
        <source>Tile Layer 1</source>
        <translation>Camada de Tiles 1</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::NewTilesetDialog</name>
    <message>
        <location filename="../src/tiled/newtilesetdialog.cpp" line="+123"/>
        <location line="+7"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location line="-6"/>
        <source>Failed to load tileset image &apos;%1&apos;.</source>
        <translation>Erro no carregamento da imagem de tileset &apos;%1&apos;.</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>No tiles found in the tileset image when using the given tile size, margin and spacing!</source>
        <translation>Tiles não encontrados na imagem de tileset usando o tamanho, margem e espaçamento das tiles!</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Tileset Image</source>
        <translation>Imagem de Tileset</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::ObjectGroupPropertiesDialog</name>
    <message>
        <location filename="../src/tiled/objectgrouppropertiesdialog.cpp" line="+43"/>
        <source>Object Layer</source>
        <translation>Camada de Objectos</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Color:</source>
        <translation>Cor:</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::ObjectPropertiesDialog</name>
    <message>
        <location filename="../src/tiled/objectpropertiesdialog.cpp" line="+41"/>
        <source>Object</source>
        <translation>Objecto</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation type="obsolete">Nome:</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation type="obsolete">Tipo:</translation>
    </message>
    <message>
        <location line="+47"/>
        <source>Change Object</source>
        <translation>Modificar Objecto</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::ObjectSelectionTool</name>
    <message>
        <location filename="../src/tiled/objectselectiontool.cpp" line="+103"/>
        <location line="+135"/>
        <source>Select Objects</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-132"/>
        <location line="+133"/>
        <source>S</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <location line="+77"/>
        <location line="+145"/>
        <source>Duplicate %n Object(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="-144"/>
        <location line="+162"/>
        <source>Remove %n Object(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="-153"/>
        <location line="+163"/>
        <source>Move %n Object(s) to Layer</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <location line="-153"/>
        <source>Object &amp;Properties...</source>
        <translation type="unfinished">Objectos &amp;Propriedades...</translation>
    </message>
    <message numerus="yes">
        <location line="+107"/>
        <source>Move %n Object(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::PreferencesDialog</name>
    <message>
        <location filename="../src/tiled/preferencesdialog.cpp" line="+56"/>
        <location line="+23"/>
        <source>System default</source>
        <translation>Padrão do Sistema</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::PropertiesDialog</name>
    <message>
        <location filename="../src/tiled/propertiesdialog.cpp" line="+62"/>
        <source>%1 Properties</source>
        <translation>%1 Propriedades</translation>
    </message>
    <message>
        <location line="+37"/>
        <source>Layer</source>
        <translation>Camada</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::PropertiesModel</name>
    <message>
        <location filename="../src/tiled/propertiesmodel.cpp" line="+51"/>
        <source>&lt;new property&gt;</source>
        <translation>&lt;nova propriedade&gt;</translation>
    </message>
    <message>
        <location line="+68"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Value</source>
        <translation>Valor</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::SaveAsImageDialog</name>
    <message>
        <location filename="../src/tiled/saveasimagedialog.cpp" line="+111"/>
        <source>Save as Image</source>
        <translation>Salvar Como Imagem</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>%1 already exists.
Do you want to replace it?</source>
        <translation>%1 já existe.
Deseja substituí-lo?</translation>
    </message>
    <message>
        <location line="+71"/>
        <source>Image</source>
        <translation>Imagem</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::SelectionTool</name>
    <message>
        <location filename="../src/tiled/selectiontool.cpp" line="+34"/>
        <location line="+81"/>
        <source>Rectangular Select</source>
        <translation>Selecção Rectangular</translation>
    </message>
    <message>
        <location line="-78"/>
        <location line="+79"/>
        <source>R</source>
        <translation></translation>
    </message>
    <message>
        <location line="-56"/>
        <source>%1, %2 - Rectangle: (%3 x %4)</source>
        <translation>%1, %2 - Rectangulo: (%3 x %4)</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::StampBrush</name>
    <message>
        <location filename="../src/tiled/stampbrush.cpp" line="+38"/>
        <location line="+279"/>
        <source>Stamp Brush</source>
        <translation>Pincel de Carimbo</translation>
    </message>
    <message>
        <location line="-276"/>
        <location line="+277"/>
        <source>B</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::TilesetDock</name>
    <message>
        <location filename="../src/tiled/tilesetdock.cpp" line="+247"/>
        <source>Remove Tileset</source>
        <translation>Remover Tileset</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The tileset &quot;%1&quot; is still in use by the map!</source>
        <translation>A tileset &quot;%1&quot; ainda está a ser usado no mapa!</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Remove this tileset and all references to the tiles in this tileset?</source>
        <translation>Remover este tileset e todas as referências das tiles neste tileset?</translation>
    </message>
    <message>
        <location line="+58"/>
        <source>Tilesets</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::TilesetView</name>
    <message>
        <source>Properties...</source>
        <translation type="obsolete">Propriedades...</translation>
    </message>
    <message>
        <location filename="../src/tiled/tilesetview.cpp" line="+210"/>
        <source>Tile &amp;Properties...</source>
        <translation>&amp;Propriedades do Tile...</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>&amp;Export Tileset As...</source>
        <translation>&amp;Exportar Tileset Como...</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&amp;Import Tileset</source>
        <translation>&amp;Importar Tileset</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Tile</source>
        <translation>Tile</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Export Tileset</source>
        <translation>Export Tileset</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Tiled tileset files (*.tsx)</source>
        <translation>Ficheiros de tileset do Tiled (*.tmx)</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::ToolManager</name>
    <message>
        <location filename="../src/tiled/toolmanager.cpp" line="+88"/>
        <source>Tools</source>
        <translation>Ferramentas</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::UndoDock</name>
    <message>
        <source>Undo Stack</source>
        <translation type="obsolete">Histórico</translation>
    </message>
    <message>
        <location filename="../src/tiled/undodock.cpp" line="+64"/>
        <source>History</source>
        <translation>Histórico</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&lt;empty&gt;</source>
        <translation>&lt;vazio&gt;</translation>
    </message>
</context>
<context>
    <name>Tmw::TmwPlugin</name>
    <message>
        <location filename="../src/plugins/tmw/tmwplugin.cpp" line="+47"/>
        <source>Multiple collision layers found!</source>
        <translation>Multiplas layers de colisão encontradas!</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>No collision layer found!</source>
        <translation>Layer de colisãom não encontrada!</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Could not open file for writing.</source>
        <translation>Impossivel abrir para escrita.</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>TMW-eAthena collision files (*.wlk)</source>
        <translation>Ficheiros de colisão TMW-eAthena (*.wlk)</translation>
    </message>
    <message>
        <source>TMW-eAthena collision files 2 (*.wlk2)</source>
        <translation type="obsolete">Ficheiros de colisão TMW-eAthena 2 (*.wlk2)</translation>
    </message>
</context>
<context>
    <name>TmxMapReader</name>
    <message>
        <source>XML map reader (*.tmx)</source>
        <translation type="obsolete">Leitor de mapas XML (*.tmx)</translation>
    </message>
    <message>
        <source>Could not open file for writing.</source>
        <translation type="obsolete">Impossivel abrir para escrita.</translation>
    </message>
    <message>
        <source>XML map writer (*.tmx)</source>
        <translation type="obsolete">Escrita de mapas XML (*.tmx)</translation>
    </message>
    <message>
        <location filename="../src/tiled/tmxmapreader.h" line="+55"/>
        <location filename="../src/tiled/tmxmapwriter.h" line="+56"/>
        <source>Tiled map files (*.tmx)</source>
        <translation>Ficheiros de mapa do Tiled (*.tmx)</translation>
    </message>
</context>
<context>
    <name>TmxReader</name>
    <message>
        <source>Not a map file.</source>
        <translation type="obsolete">Não é um ficheiro de Mapa.</translation>
    </message>
    <message>
        <source>Not a tileset file.</source>
        <translation type="obsolete">Não é um ficheiro de tileset.</translation>
    </message>
    <message>
        <source>%3

Line %1, column %2</source>
        <translation type="obsolete">%3

Linha %1, coluna %2</translation>
    </message>
    <message>
        <source>File not found: %1</source>
        <translation type="obsolete">Ficheiro não encontrado: %1</translation>
    </message>
    <message>
        <source>Unable to read file: %1</source>
        <translation type="obsolete">Incapaz de ler ficheiro: %1</translation>
    </message>
    <message>
        <source>Unsupported map orientation: &quot;%1&quot;</source>
        <translation type="obsolete">Orientação de mapa não suportado: &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Invalid tileset parameters for tileset &apos;%1&apos;</source>
        <translation type="obsolete">Parametros de tileset inválidos para tileset &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Error while loading tileset &apos;%1&apos;: %2</source>
        <translation type="obsolete">Erro a carregar tileset &apos;%1&apos;: %2</translation>
    </message>
    <message>
        <source>Invalid tile ID: %1</source>
        <translation type="obsolete">Tile ID inválido: %1</translation>
    </message>
    <message>
        <source>Error loading tileset image:
&apos;%1&apos;</source>
        <translation type="obsolete">Erroa a Carregar a imagem de tileser:
&apos;%1&apos;</translation>
    </message>
    <message>
        <source>Too many &lt;tile&gt; elements</source>
        <translation type="obsolete">Demaseados elementos &lt;tile&gt;</translation>
    </message>
    <message>
        <source>Invalid tile: %1</source>
        <translation type="obsolete">Tile inválido: %1</translation>
    </message>
    <message>
        <source>Unknown encoding: %1</source>
        <translation type="obsolete">Codificação desconhecida: %1</translation>
    </message>
    <message>
        <source>Compression method &apos;%1&apos; not supported</source>
        <translation type="obsolete">Método de compressão &apos;%1&apos; não suportado</translation>
    </message>
    <message>
        <source>Corrupt layer data for layer &apos;%1&apos;</source>
        <translation type="obsolete">Data de Camada corrumpido para a Camada &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Unable to parse tile at (%1,%2) on layer &apos;%3&apos;</source>
        <translation type="obsolete">Incapaz de intrepertar tile em (%1,%2) na camada &apos;%3&apos;</translation>
    </message>
    <message>
        <source>Invalid global tile id (less than 0): %1</source>
        <translation type="obsolete">ID global de tile inválido (inferior a 0): %1</translation>
    </message>
    <message>
        <source>Tile used but no tilesets specified</source>
        <translation type="obsolete">Tile usado mas nenhum tileset especificado</translation>
    </message>
</context>
<context>
    <name>TmxViewer</name>
    <message>
        <location filename="../src/tmxviewer/tmxviewer.cpp" line="+166"/>
        <source>TMX Viewer</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Undo Commands</name>
    <message>
        <location filename="../src/tiled/addremovelayer.h" line="+67"/>
        <source>Add Layer</source>
        <translation>Addicionar Camada</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Remove Layer</source>
        <translation>Remover Camada</translation>
    </message>
    <message>
        <location filename="../src/tiled/addremovemapobject.cpp" line="+76"/>
        <source>Add Object</source>
        <translation>Adicionar Objecto</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Remove Object</source>
        <translation>Remover Objecto</translation>
    </message>
    <message>
        <location filename="../src/tiled/changemapobject.cpp" line="+35"/>
        <source>Change Object</source>
        <translation>Modificar Objecto</translation>
    </message>
    <message>
        <location filename="../src/tiled/changeproperties.cpp" line="+34"/>
        <source>Change %1 Properties</source>
        <translation>Mudar %1 Propriedades</translation>
    </message>
    <message>
        <location filename="../src/tiled/changeselection.cpp" line="+31"/>
        <source>Change Selection</source>
        <translation>Mudar Selecção</translation>
    </message>
    <message>
        <location filename="../src/tiled/erasetiles.cpp" line="+39"/>
        <source>Erase</source>
        <translation>Apagar</translation>
    </message>
    <message>
        <location filename="../src/tiled/movelayer.cpp" line="+37"/>
        <source>Move Layer Down</source>
        <translation>Mover Camada para Baixo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Move Layer Up</source>
        <translation>Mover Camada para Cima</translation>
    </message>
    <message>
        <location filename="../src/tiled/movemapobject.cpp" line="+39"/>
        <source>Move Object</source>
        <translation>Mover Objecto</translation>
    </message>
    <message>
        <location filename="../src/tiled/offsetlayer.cpp" line="+40"/>
        <source>Offset Layer</source>
        <translation>Deslocamento da Camada</translation>
    </message>
    <message>
        <location filename="../src/tiled/painttilelayer.cpp" line="+49"/>
        <source>Paint</source>
        <translation>PPintar</translation>
    </message>
    <message>
        <location filename="../src/tiled/renamelayer.cpp" line="+40"/>
        <source>Rename Layer</source>
        <translation>Renomear Camada</translation>
    </message>
    <message>
        <location filename="../src/tiled/resizelayer.cpp" line="+37"/>
        <source>Resize Layer</source>
        <translation>Redimensionar Camada</translation>
    </message>
    <message>
        <location filename="../src/tiled/resizemap.cpp" line="+32"/>
        <source>Resize Map</source>
        <translation>Redimensionar Mapa</translation>
    </message>
    <message>
        <location filename="../src/tiled/resizemapobject.cpp" line="+39"/>
        <source>Resize Object</source>
        <translation>Redimensionar Objecto</translation>
    </message>
    <message>
        <location filename="../src/tiled/changeobjectgroupproperties.cpp" line="+37"/>
        <location filename="../src/tiled/objectgrouppropertiesdialog.cpp" line="+21"/>
        <source>Change Object Layer Properties</source>
        <translation>Mudificar Propriedades da Camada de Objectos</translation>
    </message>
    <message>
        <location filename="../src/tiled/filltiles.cpp" line="+36"/>
        <source>Fill Area</source>
        <translation>Área de Preênchimento</translation>
    </message>
    <message>
        <location filename="../src/tiled/addremovetileset.cpp" line="+62"/>
        <source>Add Tileset</source>
        <translation>Adicionar Tileset</translation>
    </message>
    <message>
        <location filename="../src/tiled/addremovetileset.h" line="+78"/>
        <source>Remove Tileset</source>
        <translation>Remover Tileset</translation>
    </message>
    <message>
        <location filename="../src/tiled/movetileset.cpp" line="+31"/>
        <source>Move Tileset</source>
        <translation>Mover Tileset</translation>
    </message>
    <message>
        <location filename="../src/tiled/tilesetview.cpp" line="-151"/>
        <source>Import Tileset</source>
        <translation>Importar Tileset</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Export Tileset</source>
        <translation>Exportar Tileset</translation>
    </message>
    <message>
        <location filename="../src/tiled/movemapobjecttogroup.cpp" line="+40"/>
        <source>Move Object to Layer</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <location filename="../src/tiled/utils.cpp" line="+31"/>
        <source>Image files</source>
        <translation>Ficheiros de imagem</translation>
    </message>
</context>
</TS>
